<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Zarządzanie użytkownikiem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administracja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Dodaj nowego użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Dodaj konto użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Wprowadź ponownie hasło dla nowego użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>potwierdź hasło</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <source>Username of new user</source>
        <translation>Nazwa nowego użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>User login name:</source>
        <translation>Login użytkownika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <location filename="../mainwindow.ui" line="416"/>
        <location filename="../mainwindow.ui" line="1134"/>
        <source>Enter username of new user</source>
        <translation>Podaj nazwę nowego użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="422"/>
        <source>username</source>
        <translation>nazwa użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Password for new user</source>
        <translation>Hasło dla nowego użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>User password:</source>
        <translation>Hasło użytkownika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Enter password for new user</source>
        <translation>Podaj hasło dla nowego użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>password</source>
        <translation>hasło</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Confirm user password:</source>
        <translation>Potwierdź hasło użytkownika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Delete User Account</source>
        <translation>Usuń konto użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Select user</source>
        <translation>Wybierz użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.ui" line="1222"/>
        <location filename="../mainwindow.ui" line="1346"/>
        <location filename="../mainwindow.ui" line="1368"/>
        <source>Select user to delete</source>
        <translation>Wybierz użytkownika do usunięcia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>User to delete:</source>
        <translation>Użytkownik do usunięcia:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Usuń także katalog domowy użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Delete user home directory</source>
        <translation>Usuń katalog domowy użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Rename User Account</source>
        <translation>Zmień Nazwę Konta Użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to modify:</source>
        <translation>Wybierz użytkownika, którego chcesz zmodyfikować:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>New user name:</source>
        <translation>Nowa nazwa użytkownika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Change User Password</source>
        <translation>Zmień hasło użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>new password</source>
        <translation>nowe hasło</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Confirm new password:</source>
        <translation>Potwierdź nowe hasło:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>confirm new password</source>
        <translation>potwierdź nowe hasło</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>New user password:</source>
        <translation>Nowe hasło użytkownika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Repair a user configuration</source>
        <translation>Napraw konfigurację użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Modify User Account</source>
        <translation>Zmodyfikuj konto użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Select user to repair</source>
        <translation>Wybierz użytkownika do naprawy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <location filename="../mainwindow.ui" line="1355"/>
        <source>User to change:</source>
        <translation>Użytkownik do zmiany:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="624"/>
        <source>Restore Defaults</source>
        <translation>Przywróć domyślne</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Przywróć konfigurację przeglądarki do wartości domyślnych MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="651"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Konfiguracja przeglądarki Mozilla (Iceweasel lub Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Przywróć członkostwo w grupach do wartości domyślnych MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Group memberships</source>
        <translation>Członkostwo w grupach</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Change Autologin Settings</source>
        <translation>Zmień ustawienia automatycznego logowania</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Log in automatically</source>
        <translation>Zaloguj się automatycznie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Require password to log in</source>
        <translation>Wymagaj hasła, aby się zalogować</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy/Sync</source>
        <translation>Kopiuj/synchronizuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Copy Between Desktops</source>
        <translation>Kopiuj pomiędzy pulpitami</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <location filename="../mainwindow.ui" line="829"/>
        <source>Select desktop to copy from</source>
        <translation>Wybierz pulpit źródłowy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>Select to only copy files</source>
        <translation>Wybierz by skopiować tylko pliki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Copy only</source>
        <translation>Kopiuj tylko</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Select desktop to copy to</source>
        <translation>Wybierz pulpit docelowy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <source>Copy to:</source>
        <translation>Kopia do (pulpit docelowy):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Copy from:</source>
        <translation>Kopia z (pulpit źródłowy):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>Select to copy and then delete differences</source>
        <translation>Wybierz by skopiować, a następnie usunąć różnice</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="854"/>
        <source>Sync</source>
        <translation>Synchronizacja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select to copy/sync Shared</source>
        <translation>Wybierz by skopiować/zsynchronizować tylko Współdzielone</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="903"/>
        <source>Shared folder</source>
        <translation>Folder współdzielony</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Select to copy/sync entire home</source>
        <translation>Wybierz by skopiować/zsynchronizować cały katalog domowy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Entire home</source>
        <translation>Cały katalog domowy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="935"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Wybierz by skopiować/zsynchronizować konfigurację przeglądarki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="938"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Konfiguracja przeglądarki Mozilla (Iceweasel/Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="951"/>
        <source>Select to copy/sync Documents</source>
        <translation>Wybierz by skopiować/zsynchronizować Dokumenty</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Documents folder</source>
        <translation>Folder Dokumenty</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="961"/>
        <source>What to copy/sync:</source>
        <translation>Co kopiować/zsynchronizować:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="977"/>
        <source>Progress</source>
        <translation>Postęp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1007"/>
        <location filename="../mainwindow.ui" line="1023"/>
        <source>Status of the changes</source>
        <translation>Status zmian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1026"/>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1042"/>
        <source>Progress of the changes</source>
        <translation>Postęp zmian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1079"/>
        <source>Add/Remove Groups</source>
        <translation>Dodaj/Usuń grupy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1091"/>
        <source>Add Group</source>
        <translation>Dodaj grupę</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1121"/>
        <source>Group name:</source>
        <translation>Nazwa grupy:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>groupname</source>
        <translation>nazwa grupy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1169"/>
        <source>Delete Group</source>
        <translation>Usuń grupę</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1231"/>
        <source>Group to delete:</source>
        <translation>Grupa do usunięcia:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Group Membership</source>
        <translation>Przynależność użytkowników do grupy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1375"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Grupy do których przynależy użytkownik (zmień grupy zaznaczając/odznaczając odpowiednie pola):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1395"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation>*Proszę upewnij się, że wybrałeś właściwie przed zapisaniem zmian. Wybór błędnych grup może zepsuć Twój system. Jeśli popełnisz błąd, użyj karty Naprawa by przywrócić oryginalne przynależności grup.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Apply any changes</source>
        <translation>Zastosuj wszystkie zmiany</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Cancel any changes then quit</source>
        <translation>Anuluj wszystkie zmiany, a następnie zakończ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1475"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Display help </source>
        <translation>Wyświetl pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1526"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1533"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1540"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1543"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1550"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="112"/>
        <location filename="../mainwindow.cpp" line="174"/>
        <location filename="../mainwindow.cpp" line="182"/>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="219"/>
        <location filename="../mainwindow.cpp" line="242"/>
        <location filename="../mainwindow.cpp" line="250"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <location filename="../mainwindow.cpp" line="690"/>
        <location filename="../mainwindow.cpp" line="718"/>
        <location filename="../mainwindow.cpp" line="726"/>
        <location filename="../mainwindow.cpp" line="916"/>
        <location filename="../mainwindow.cpp" line="1029"/>
        <source>none</source>
        <translation>żaden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Konfiguracja użytkownika zostanie naprawiona. Zamknij teraz wszystkie inne aplikacje. Po zakończeniu wyloguj się lub uruchom ponownie. Czy na pewno chcesz teraz dokonać naprawy?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <location filename="../mainwindow.cpp" line="312"/>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <location filename="../mainwindow.cpp" line="312"/>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Autologin options</source>
        <translation>Opcje automatycznego logowania</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Automatyczne logowanie zostało wyłączone dla konta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Automatyczne logowanie zostało włączone dla konta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Musisz określić miejsce docelowe dla &apos;Kopiuj do&apos;. Nie możesz kopiować na pulpit, do którego jesteś zalogowany.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Przed kopiowaniem zamknij wszystkie inne aplikacje. Upewnij się, że miejsce docelowe do którego kopiujesz posiada wystarczającą przestrzeń dyskową by pomieścić wszystkie kopiowane pliki. Kopiowanie pomiędzy pulpitami może nadpisać lub skasować wszystkie Twoje pliki i konfiguracje na pulpicie docelowym. Na pewno chcesz kontynuować?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Synchronizing desktop...</source>
        <translation>Synchronizacja pulpitu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Copying desktop...</source>
        <translation>Kopiowanie pulpitu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Nazwa użytkownika musi mieć przynajmniej 2 znaki. Proszę wybierz dłuższą nazwę, aby kontynuować.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Nazwa użytkownika musi być pisana małymi literami
i nie może zawierać znaków specjalnych ani spacji.
Wybierz inną nazwę, zanim przejdziesz dalej.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Przepraszamy, ta nazwa jest już wykorzystywana. Wybierz inną nazwę.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Hasła nie pasują do siebie. Proszę spróbuj ponownie.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Hasło musi mieć co najmniej 2 znaki. Podaj dłuższe hasło, zanim przejdziesz dalej.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>The user was added ok.</source>
        <translation>Użytkownik został dodany.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>Failed to add the user.</source>
        <translation>Nie udało się dodać użytkownika.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Password successfully changed.</source>
        <translation>Hasło zostało pomyślnie zmienione.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Failed to change password.</source>
        <translation>Nie udało się zmienić hasła.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Tego działania nie można cofnąć. Czy na pewno chcesz usunąć użytkownika %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>The user has been deleted.</source>
        <translation>Użytkownik został usunięty. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Failed to delete the user.</source>
        <translation>Nie można usunąć użytkownika.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Nazwa grupy musi mieć co najmniej 2 znaki. Wybierz dłuższą nazwę, zanim przejdziesz dalej.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Nazwa grupy musi być pisana małymi literami
i nie może zawierać znaków specjalnych ani spacji.
Wybierz inną nazwę, zanim przejdziesz dalej.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Przepraszamy, ta nazwa grupy już istnieje. Wybierz inną nazwę.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>The system group was added ok.</source>
        <translation>Grupa systemowa została dodana.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <source>Failed to add the system group.</source>
        <translation>Nie można dodać grupy systemowej.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Tego działania nie można cofnąć. Czy na pewno chcesz usunąć grupę %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="499"/>
        <source>The group has been deleted.</source>
        <translation>Grupa została usunięta.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Failed to delete the group.</source>
        <translation>Nie udało się usunąć grupy.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>The changes have been applied.</source>
        <translation>Zmiany zostały wprowadzone.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Failed to apply group changes</source>
        <translation>Nie udało się zastosować zmian grup</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>The selected user name is currently in use.</source>
        <translation>Wybrana nazwa użytkownika jest już zajęta.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Aby zmienić nazwę użytkownika, proszę się wylogować i zalogować używając innego konta.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="561"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Przepraszamy, ta nazwa jest już wykorzystywana. Wybierz inną nazwę.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Nie udało się zmienić nazwy użytkownika. Proszę upewnić się, że użytkownik nie jest zalogowany, może być konieczne ponowne uruchomienie.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>The user was renamed.</source>
        <translation>Nazwa użytkownika została zmieniona.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="595"/>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Synchronizowanie pulpitu... OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="597"/>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Copying desktop...ok</source>
        <translation>Kopiowanie pulpitu... OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Synchronizowanie pulpitu... NIE POWIODŁO SIĘ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Copying desktop...failed</source>
        <translation>Kopiowanie pulpitu... NIE POWIODŁO SIĘ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="669"/>
        <location filename="../mainwindow.cpp" line="968"/>
        <location filename="../mainwindow.cpp" line="976"/>
        <source>browse...</source>
        <translation>przeglądaj...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="853"/>
        <source>About MX User Manager</source>
        <translation>O programie MX Zarządzanie użytkownikiem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="854"/>
        <source>MX User Manager</source>
        <translation>MX Zarządzanie użytkownikiem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="856"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Prosta konfiguracja użytkownika dla systemu MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="857"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="859"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="860"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="969"/>
        <source>Select folder to copy to</source>
        <translation>Wybierz folder do którego chcesz skopiować</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="41"/>
        <source>You must run this program as root.</source>
        <translation>Musisz uruchomić ten program jako administrator. </translation>
    </message>
</context>
</TS>
